package mvd.jester.priority;

import java.util.Arrays;
import java.util.HashSet;
import java.util.Set;
import mvd.jester.model.Task;
import mvd.jester.tests.AbstractTest;
import mvd.jester.tests.ChwaLee;

/**
 * EarliestDeadineFirst
 */
public class EarliestDeadlineFirst implements PriorityManager {

    final static Set<Class<? extends AbstractTest<? extends Task>>> abstractTests =
            new HashSet<>(Arrays.asList(ChwaLee.class));

    /**
     * Compare the priority of two tasks according to the Rate Monotonic policy
     * 
     * @param t1 The first task
     * @param t2 The second task
     * @return 0 if both tasks have the same priority, positive number if the first task has a
     *         higher priority, negative number if the second task has a higher priority
     */
    @Override
    public int compare(Task t1, Task t2) {
        return (int) (t1.getDeadline() - t2.getDeadline());
    }

    @Override
    public boolean hasTest(AbstractTest<? extends Task> abstractTest) {
        return abstractTests.contains(abstractTest.getClass());
    }

    @Override
    public boolean hasTest(Class<? extends AbstractTest<? extends Task>> abstractTestClass) {
        return abstractTests.contains(abstractTestClass);
    }

    @Override
    public String getName() {
        return "EDF";
    }

}
